@@ -1,4 +1,4 @@
-/* Copyright (c) 2002, 2003, 2004, 2005  Eric B. Weddington
+/* Copyright (c) 2002, 2003, 2004, 2005, 2006, 2007  Eric B. Weddington
    All rights reserved.
 
    Redistribution and use in source and binary forms, with or without
@@ -26,11 +26,12 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: boot.h,v 1.20.2.1 2006/01/22 19:35:30 joerg_wunsch Exp $ */
+/* $Id: boot.h,v 1.27 2007/12/18 22:22:14 joerg_wunsch Exp $ */
 
 #ifndef _AVR_BOOT_H_
 #define _AVR_BOOT_H_    1
 
+/** \file */
 /** \defgroup avr_boot <avr/boot.h>: Bootloader Support Utilities
     \code
     #include <avr/io.h>
@@ -41,6 +42,11 @@
     bootloader support functionality of certain AVR processors. These
     macros are designed to work with all sizes of flash memory.
 
+    Global interrupts are not automatically disabled for these macros. It
+    is left up to the programmer to do this. See the code example below. 
+    Also see the processor datasheet for caveats on having global interrupts 
+    enabled during writing of the Flash.
+
     \note Not all AVR processors provide bootloader support. See your
     processor datasheet to see if it provides bootloader support.
 
@@ -488,6 +494,35 @@
     __result;                                              \
 }))
 
+/** \ingroup avr_boot
+    \def boot_signature_byte_get(address)
+
+    Read the Signature Row byte at \c address.  For some MCU types,
+    this function can also retrieve the factory-stored oscillator
+    calibration bytes.
+
+    Parameter \c address can be 0-0x1f as documented by the datasheet.
+    \note The values are MCU type dependent.
+*/
+
+#define __BOOT_SIGROW_READ (_BV(SPMEN) | _BV(SIGRD))
+
+#define boot_signature_byte_get(addr) \
+  (__extension__({		      \
+      uint16_t __addr16 = (uint16_t)(addr);	\
+      uint8_t __result;				\
+      __asm__ __volatile__			\
+      (						\
+	"sts %1, %2\n\t"			\
+	"lpm %0, Z" "\n\t"			\
+	: "=r" (__result)			\
+	: "i" (_SFR_MEM_ADDR(__SPM_REG)),	\
+	  "r" ((uint8_t) __BOOT_SIGROW_READ),	\
+	  "z" (__addr16)			\
+      );					\
+      __result;					\
+}))
+
 /** \ingroup avr_boot
     \def boot_page_fill(address, data)
 
@@ -534,7 +569,7 @@
     Loader memory section of flash, you would use this macro as such:
 
     \code
-    boot_lock_bits_set (_BV (BLB12));
+    boot_lock_bits_set (_BV (BLB11));
     \endcode
 
     \note Like any lock bits, the Boot Loader Lock Bits, once set,
@@ -559,7 +594,7 @@
 #define boot_rww_enable()             __boot_rww_enable_alternate()
 #define boot_lock_bits_set(lock_bits) __boot_lock_bits_set_alternate(lock_bits)
 
-#elif (FLASHEND > USHRT_MAX) && (__USING_MINT8)
+#elif (FLASHEND > USHRT_MAX)
 
 /* Extended: >16 bit address */
 #define boot_page_fill(address, data) __boot_page_fill_extended(address, data)
