@@ -1,4 +1,4 @@
-/* Copyright (c) 2002, 2003, 2004 Marek Michalkiewicz
+/* Copyright (c) 2002, 2003, 2004, 2007 Marek Michalkiewicz
    Copyright (c) 2005, 2006 Bjoern Haase
    All rights reserved.
 
@@ -29,7 +29,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: eeprom.h,v 1.17.2.1 2006/02/26 21:51:04 aesok Exp $ */
+/* $Id: eeprom.h,v 1.21 2007/01/23 15:32:48 joerg_wunsch Exp $ */
 
 /*
    eeprom.h
@@ -49,6 +49,7 @@
 #include <stddef.h>
 #include <inttypes.h>
 
+/** \file */
 
 #ifdef __AVR_MEGA__
 #define XCALL "call"
@@ -189,7 +190,7 @@ uint8_t
 eeprom_read_byte (const uint8_t *addr) 
 {
   uint8_t result;
-  asm volatile
+  __asm__ __volatile__
       ( XCALL " __eeprom_read_byte_" _REG_LOCATION_SUFFIX CR_TAB
         "mov %1,__tmp_reg__"
        : "+x" (addr),
@@ -205,7 +206,7 @@ eeprom_read_word (const uint16_t *addr)
 {
   uint16_t result;
 
-  asm ( 
+  __asm__ __volatile__ (
         XCALL " __eeprom_read_word_" _REG_LOCATION_SUFFIX CR_TAB
        : "+x" (addr),
          "=z" (result)
@@ -230,7 +231,7 @@ eeprom_read_block (void *pointer_ram,
       /* make sure size is a 16 bit variable.  */
       uint16_t size = n; 
 
-      asm volatile ( 
+      __asm__ __volatile__ ( 
             ".%=_start:" CR_TAB
             "sbiw %2,1" CR_TAB
             "brlt .%=_finished" CR_TAB
@@ -251,7 +252,7 @@ eeprom_read_block (void *pointer_ram,
         {
           if (n == 256)
             {
-              asm volatile (
+              __asm__ __volatile__ (
                   XCALL " __eeprom_read_block_" _REG_LOCATION_SUFFIX 
                 : "+x" (pointer_eeprom),
                   "=z" (pointer_ram)
@@ -264,7 +265,7 @@ eeprom_read_block (void *pointer_ram,
               uint8_t len;
               len = (uint8_t) n; 
 
-              asm volatile (
+              __asm__ __volatile__ (
                   "mov __zero_reg__,%2"      CR_TAB
                    XCALL " __eeprom_read_block_" _REG_LOCATION_SUFFIX 
                 : "+x" (pointer_eeprom),
@@ -283,7 +284,7 @@ eeprom_read_block (void *pointer_ram,
 void 
 eeprom_write_byte (uint8_t *addr,uint8_t value)
 {
-  asm volatile (
+  __asm__ __volatile__ (
          "mov __tmp_reg__,%1"      CR_TAB
          XCALL " __eeprom_write_byte_" _REG_LOCATION_SUFFIX
        : "+x" (addr)
@@ -298,8 +299,8 @@ eeprom_write_byte (uint8_t *addr,uint8_t value)
 void 
 eeprom_write_word (uint16_t *addr,uint16_t value)
 {
-  asm volatile (
-#if __AVR_HAVE_MOVW__
+  __asm__ __volatile__ (
+#if defined(__AVR_HAVE_MOVW__)
          "movw __tmp_reg__,%A1" CR_TAB
 #else
          "mov __tmp_reg__,%A1"      CR_TAB
@@ -327,7 +328,7 @@ eeprom_write_block (const void *pointer_ram,
       /* make sure size is a 16 bit variable.  */
       uint16_t size = n; 
 
-      asm volatile ( 
+      __asm__ __volatile__ ( 
             ".%=_start:" CR_TAB
             "sbiw %2,1" CR_TAB
             "brlt .%=_finished" CR_TAB
@@ -349,7 +350,7 @@ eeprom_write_block (const void *pointer_ram,
         {
           if (n == 256)
             {
-              asm volatile (
+              __asm__ __volatile__ (
                  XCALL " __eeprom_write_block_" _REG_LOCATION_SUFFIX
                : "+x" (pointer_eeprom),
                  "=z" (pointer_ram)
@@ -361,7 +362,7 @@ eeprom_write_block (const void *pointer_ram,
               uint8_t len;
               len = (uint8_t) n;
 
-              asm volatile (
+              __asm__ __volatile__ (
                  "mov __zero_reg__,%2" CR_TAB
                  XCALL " __eeprom_write_block_" _REG_LOCATION_SUFFIX
                : "+x" (pointer_eeprom),
