@@ -1,4 +1,4 @@
-/* Copyright (c) 2002, 2003, 2004,2005  Marek Michalkiewicz
+/* Copyright (c) 2002 - 2007  Marek Michalkiewicz
    All rights reserved.
 
    Redistribution and use in source and binary forms, with or without
@@ -26,7 +26,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: pgmspace.h,v 1.26.2.1 2005/12/18 14:03:40 aesok Exp $ */
+/* $Id: pgmspace.h,v 1.40 2007/03/30 04:37:14 arcanum Exp $ */
 
 /*
    pgmspace.h
@@ -37,7 +37,8 @@
      Wolfgang Haidinger <wh@vmars.tuwien.ac.at> (pgm_read_dword())
  */
 
-/** \defgroup avr_pgmspace <avr/pgmspace.h>: Program Space String Utilities
+/** \file */
+/** \defgroup avr_pgmspace <avr/pgmspace.h>: Program Space Utilities
     \code
     #include <avr/io.h>
     #include <avr/pgmspace.h>
@@ -56,10 +57,20 @@
     \note If you are working with strings which are completely based in ram,
     use the standard string functions described in \ref avr_string.
 
-    \note If possible, put your constant tables in the lower 64K and use
+    \note If possible, put your constant tables in the lower 64 KB and use
     pgm_read_byte_near() or pgm_read_word_near() instead of
     pgm_read_byte_far() or pgm_read_word_far() since it is more efficient that
-    way, and you can still use the upper 64K for executable code. */
+    way, and you can still use the upper 64K for executable code.
+    All functions that are suffixed with a \c _P \e require their
+    arguments to be in the lower 64 KB of the flash ROM, as they do
+    not use ELPM instructions.  This is normally not a big concern as
+    the linker setup arranges any program space constants declared
+    using the macros from this header file so they are placed right after
+    the interrupt vectors, and in front of any executable code.  However,
+    it can become a problem if there are too many of these constants, or
+    for bootloaders on devices with more than 64 KB of ROM.
+    <em>All these functions will not work in that situation.</em>
+*/
 
 #ifndef __PGMSPACE_H_
 #define __PGMSPACE_H_ 1
@@ -179,6 +190,9 @@ typedef uint32_t PROGMEM prog_uint32_t;
    \typedef prog_int64_t
 
    Type of an "int64_t" object located in flash ROM.
+
+   \note This type is not available when the compiler
+   option -mint8 is in effect.
 */
 typedef int64_t PROGMEM prog_int64_t;
 
@@ -187,6 +201,9 @@ typedef int64_t PROGMEM prog_int64_t;
    \typedef prog_uint64_t
 
    Type of an "uint64_t" object located in flash ROM.
+
+   \note This type is not available when the compiler
+   option -mint8 is in effect.
 */
 typedef uint64_t PROGMEM prog_uint64_t;
 #else  /* !DOXYGEN */
@@ -200,8 +217,10 @@ typedef int16_t   prog_int16_t  PROGMEM;
 typedef uint16_t  prog_uint16_t PROGMEM;
 typedef int32_t   prog_int32_t  PROGMEM;
 typedef uint32_t  prog_uint32_t PROGMEM;
+#if !__USING_MINT8
 typedef int64_t   prog_int64_t  PROGMEM;
 typedef uint64_t  prog_uint64_t PROGMEM;
+#endif
 #endif /* defined(__DOXYGEN__) */
 
 /* Although in C, we can get away with just using __c, it does not work in
@@ -329,7 +348,7 @@ typedef uint64_t  prog_uint64_t PROGMEM;
     __result;                               \
 }))
 
-#if defined (__AVR_ENHANCED__)
+#if defined (__AVR_HAVE_LPMX__)
 #define __LPM(addr)         __LPM_enhanced__(addr)
 #define __LPM_word(addr)    __LPM_word_enhanced__(addr)
 #define __LPM_dword(addr)   __LPM_dword_enhanced__(addr)
@@ -508,7 +527,7 @@ typedef uint64_t  prog_uint64_t PROGMEM;
     __result;                             \
 }))
 
-#if defined (__AVR_ENHANCED__)
+#if defined (__AVR_HAVE_LPMX__)
 #define __ELPM(addr)        __ELPM_enhanced__(addr)
 #define __ELPM_word(addr)   __ELPM_word_enhanced__(addr)
 #define __ELPM_dword(addr)  __ELPM_dword_enhanced__(addr)
@@ -593,11 +612,19 @@ typedef uint64_t  prog_uint64_t PROGMEM;
 #define PGM_VOID_P const prog_void *
 #endif
 
+extern PGM_VOID_P memchr_P(PGM_VOID_P s, int val, size_t len) __ATTR_CONST__;
+extern int memcmp_P(const void *, PGM_VOID_P, size_t) __ATTR_PURE__;
 extern void *memcpy_P(void *, PGM_VOID_P, size_t);
+extern void *memmem_P(const void *, size_t, PGM_VOID_P, size_t) __ATTR_PURE__;
+extern PGM_VOID_P memrchr_P(PGM_VOID_P s, int val, size_t len) __ATTR_CONST__;
 extern char *strcat_P(char *, PGM_P);
+extern PGM_P strchr_P(PGM_P s, int val) __ATTR_CONST__;
+extern PGM_P strchrnul_P(PGM_P s, int val) __ATTR_CONST__;
 extern int strcmp_P(const char *, PGM_P) __ATTR_PURE__;
 extern char *strcpy_P(char *, PGM_P);
 extern int strcasecmp_P(const char *, PGM_P) __ATTR_PURE__;
+extern char *strcasestr_P(const char *, PGM_P) __ATTR_PURE__;
+extern size_t strcspn_P(const char *s, PGM_P reject) __ATTR_PURE__;
 extern size_t strlcat_P (char *, PGM_P, size_t );
 extern size_t strlcpy_P (char *, PGM_P, size_t );
 extern size_t strlen_P(PGM_P) __ATTR_CONST__; /* program memory can't change */
@@ -606,6 +633,10 @@ extern int strncmp_P(const char *, PGM_P, size_t) __ATTR_PURE__;
 extern int strncasecmp_P(const char *, PGM_P, size_t) __ATTR_PURE__;
 extern char *strncat_P(char *, PGM_P, size_t);
 extern char *strncpy_P(char *, PGM_P, size_t);
+extern char *strpbrk_P(const char *s, PGM_P accept) __ATTR_PURE__;
+extern PGM_P strrchr_P(PGM_P s, int val) __ATTR_CONST__;
+extern char *strsep_P(char **sp, PGM_P delim);
+extern size_t strspn_P(const char *s, PGM_P accept) __ATTR_PURE__;
 extern char *strstr_P(const char *, PGM_P) __ATTR_PURE__;
 
 #ifdef __cplusplus
