@@ -33,7 +33,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE.
 
-  $Id: stdlib.h,v 1.24.2.6 2007/12/19 13:55:12 dmix Exp $
+  $Id: stdlib.h,v 1.33 2007/12/19 14:00:27 dmix Exp $
 */
 
 #ifndef _STDLIB_H_
@@ -611,11 +611,13 @@ extern char *dtostre(double __val, char *__s, unsigned char __prec,
    Conversion is done in the format \c "[-]d.ddd".  The minimum field
    width of the output string (including the \c '.' and the possible
    sign for negative values) is given in \c width, and \c prec determines
-   the number of digits after the decimal sign.
+   the number of digits after the decimal sign. \c width is signed value,
+   negative for left adjustment.
 
    The dtostrf() function returns the pointer to the converted string \c s.
 */
-extern char *dtostrf(double __val, char __width, char __prec, char *__s);
+extern char *dtostrf(double __val, signed char __width,
+                     unsigned char __prec, char *__s);
 
 /*@}*/
 
